import { cancelOrder, remindOrder, applyBack, undoOrder, recieveOrder, recieveOrderRefund, addRefundTime } from "@/apis/order.js"
import createOrder from '@/utils/modules/pay.js'
import { isFunction } from '@/utils/types.js'
// 详细看文档
const cOrder_status = {
	'os0_osd1': {
		text: '待接单',
	},
	'os1_osd11': {
		text: '待付款',
	},
	'os1_osd12': {
		text: '待付款(已支付定金)',
	},
	'os6_osd61': {
		text: '待发货',
	},
	'os7_osd71': {
		text: '待收货',
	},
	'os10_osd101': {
		text: '已收货',
	},
	
	'os11_osd111': {
		text: '待发货退款审核',
	},
	'os11_osd112': {
		text: '待收货退款审核',
	},
	'os11_osd113': {
		text: '已收货退款审核',
	},
	'os11_osd114': {
		text: '待收货退货审核',
	},
	'os11_osd115': {
		text: '已收货退货审核',
	},
	'os11_osd116': {
		text: '待收货退款退货审核',
	},
	'os11_osd117': {
		text: '已收货退款退货审核',
	},
	
	'os9_osd91': {
		text: '退款中',
	},
	'os9_osd93': {
		text: '退货中',
	},
	'os9_osd92': {
		text: '退货退款中',
	},
	
	'os5_osd53': {
		text: '交易完成',
	},
	
	//2是关闭，osd(order_status_d) 看文档吧，2全部关闭 
	'os2_osd28': {
		text: '交易关闭' 
	},
	'os2_osd29': {
		text: '交易关闭',
	},
	'os2_osd21': {
		text: '交易关闭' 
	},
	'os2_osd23': {
		text: '交易关闭',
	},
	'os2_osd26': {
		text: '交易关闭' 
	},
	'os2_osd211': {
		text: '交易关闭',
	},
	'os2_osd22': {
		text: '交易关闭' 
	},
	'os2_osd25': {
		text: '交易关闭',
	},
	'os2_osd27': {
		text: '交易关闭',
	},
	
	'os2_osd212': {
		text: '交易关闭',
	},
	'os2_osd213': {
		text: '交易关闭' 
	},
	'os2_osd214': {
		text: '交易关闭',
	},
	'os2_osd215': {
		text: '交易关闭' 
	},
	'os2_osd216': {
		text: '交易关闭',
	},
	'os2_osd217': {
		text: '交易关闭',
	},
}
const order_mixin = {
	filters: {
		cOrderStatus(key) {
			return cOrder_status[key].text || ''
		}
	},
	methods: {			
		
		// 取消订单
		async orderCancel(order_sn, cb) {
			try{
				const { status, data } = await cancelOrder(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '订单取消成功'})
				}
			}catch(e){
				this.$toast({title: '取消失败'})
				//TODO handle the exception
			}
		},
		
		// 提醒发货
		async orderRemind(order_sn, order_id, cb) {
			try{
				const { status, data } = await remindOrder({order_sn, order_id})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '提醒成功'})
				}
			}catch(e){
				this.$toast({title: '提醒失败'})
				//TODO handle the exception
			}
		},
		
		// 申请退款
		async applyBack(order_sn, type, cb) {
			try{
				const { status, data } = await applyBack({order_sn, apply_type: type})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '申请成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 支付
		async orderPay(order_sn) {
			await createOrder({
				order_sn
			})
		},
		
		// 撤销
		async orderUndo(order_sn, type, cb) {
			try{
				const { status, data } = await undoOrder({order_sn, cancel_type: type})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '申请成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: e.msg || '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 确认收货
		async orderRecieve(order_sn, cb) {
			try{
				const { status, data } = await recieveOrder(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '收货成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: e.msg || '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 签收退款
		async orderRefund(order_sn, cb) {
			try{
				const { status, data } = await recieveOrderRefund(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '签收成功'})
				}
			}catch(e){
				this.$toast({title:e.msg ||  '签收失败'})
				//TODO handle the exception
			}
		},
		
		// 签收退款
		async orderAddRefund(order_sn, cb) {
			try{
				const { status, data } = await addRefundTime(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '操作成功'})
				}
			}catch(e){
				this.$toast({title: e.msg || '操作失败'})
				//TODO handle the exception
			}
		}
	}
}

export default order_mixin